summaryrefslogtreecommitdiffstats
path: root/tools/lib/h5diff.h
diff options
context:
space:
mode:
authorAllen Byrne <50328838+byrnHDF@users.noreply.github.com>2023-04-18 18:21:18 (GMT)
committerGitHub <noreply@github.com>2023-04-18 18:21:18 (GMT)
commit445fcab52f92bbd03ee0779e753c1cf1c1b3a91b (patch)
tree63c89e344c4b0408f9e647ed14a354569e621857 /tools/lib/h5diff.h
parent6e516abc29ce608190dec4b09ab9fd6619f22d50 (diff)
downloadhdf5-445fcab52f92bbd03ee0779e753c1cf1c1b3a91b.zip
hdf5-445fcab52f92bbd03ee0779e753c1cf1c1b3a91b.tar.gz
hdf5-445fcab52f92bbd03ee0779e753c1cf1c1b3a91b.tar.bz2
Add no subsets option to h5diff like h5dump #2688 (#2756)
Diffstat (limited to 'tools/lib/h5diff.h')
-rw-r--r--tools/lib/h5diff.h45
1 files changed, 23 insertions, 22 deletions
diff --git a/tools/lib/h5diff.h b/tools/lib/h5diff.h
index 917ea6a..d16c855 100644
--- a/tools/lib/h5diff.h
+++ b/tools/lib/h5diff.h
@@ -51,28 +51,29 @@ typedef struct {
int mode_quiet; /* quiet mode: no output at all */
int mode_report; /* report mode: print the data */
int mode_verbose; /* verbose mode: print the data, list of objcets, warnings */
- int mode_verbose_level; /* control verbose details */
- int mode_list_not_cmp; /* list not comparable messages */
- int print_header; /* print header */
- int print_percentage; /* print percentage */
- int print_dims; /* print dimension index */
- int delta_bool; /* delta, absolute value to compare */
- double delta; /* delta value */
- int use_system_epsilon; /* flag to use system epsilon (1 or 0) */
- int percent_bool; /* relative error to compare*/
- double percent; /* relative error value */
- hbool_t follow_links; /* follow symbolic links */
- int no_dangle_links; /* return error when find dangling link */
- int cmn_objs; /* do we have common objects */
- int not_cmp; /* are the objects comparable */
- int contents; /* equal contents */
- int do_nans; /* consider Nans while diffing floats */
- int exclude_path; /* exclude path to an object */
- int exclude_attr_path; /* exclude path to an object */
- struct exclude_path_list *exclude; /* keep exclude path list */
- struct exclude_path_list *exclude_attr; /* keep exclude attribute list */
- int count_bool; /* count, compare up to count */
- hsize_t count; /* count value */
+ int mode_verbose_level; /* control verbose details */
+ int mode_list_not_cmp; /* list not comparable messages */
+ int print_header; /* print header */
+ int print_percentage; /* print percentage */
+ int print_dims; /* print dimension index */
+ int delta_bool; /* delta, absolute value to compare */
+ double delta; /* delta value */
+ int use_system_epsilon; /* flag to use system epsilon (1 or 0) */
+ int percent_bool; /* relative error to compare*/
+ double percent; /* relative error value */
+ hbool_t follow_links; /* follow symbolic links */
+ int no_dangle_links; /* return error when find dangling link */
+ int cmn_objs; /* do we have common objects */
+ int not_cmp; /* are the objects comparable */
+ int contents; /* equal contents */
+ int do_nans; /* consider Nans while diffing floats */
+ int disable_compact_subset; /* disable compact form of subset notation */
+ int exclude_path; /* exclude path to an object */
+ int exclude_attr_path; /* exclude path to an object */
+ struct exclude_path_list *exclude; /* keep exclude path list */
+ struct exclude_path_list *exclude_attr; /* keep exclude attribute list */
+ int count_bool; /* count, compare up to count */
+ hsize_t count; /* count value */
diff_err_t err_stat; /* an error occurred (2, error, 1, differences, 0, no error) */
hsize_t nelmts; /* total number of elements */
hsize_t hs_nelmts; /* number of elements to read at a time*/